package football

import (
	"time"

	"github.com/shopspring/decimal"

	"git.lehouerou.net/laurent/sorare/graphql"
	"git.lehouerou.net/laurent/sorare/types"
)

type StatScore struct {
	Category   types.StatCategory `graphql:"category"`
	Points     decimal.Decimal    `graphql:"points"`
	Stat       string             `graphql:"stat"`
	StatValue  decimal.Decimal    `graphql:"statValue"`
	TotalScore decimal.Decimal    `graphql:"totalScore"`
}

type PlayerGameStats struct {
	AccuratePass       int                     `graphql:"accuratePass"`
	CleanSheet         int                     `graphql:"cleanSheet"`
	CrossAccuracy      int                     `graphql:"crossAccuracy"`
	DuelWon            int                     `graphql:"duelWon"`
	EffectiveClearance int                     `graphql:"effectiveClearance"`
	FieldStatus        types.PlayerFieldStatus `graphql:"fieldStatus"`
	FormationPlace     int                     `graphql:"formationPlace"`
	Fouls              int                     `graphql:"fouls"`
	Game               struct {
		Id graphql.Id `graphql:"id"`
	} `graphql:"game"`
	GameStarted        int        `graphql:"gameStarted"`
	GoalAssist         int        `graphql:"goalAssist"`
	GoalKicks          int        `graphql:"goalKicks"`
	Goals              int        `graphql:"goals"`
	GoalsConceded      int        `graphql:"goalsConceded"`
	Id                 graphql.Id `graphql:"id"`
	Live               bool       `graphql:"live"`
	LostCorners        int        `graphql:"lostCorners"`
	MinsPlayed         int        `graphql:"minsPlayed"`
	OnGameSheet        bool       `graphql:"onGameSheet"`
	OntargetScoringAtt int        `graphql:"ontargetScoringAtt"`
	OwnGoals           int        `graphql:"ownGoals"`
	Parries            int        `graphql:"parries"`
	PassAccuracy       int        `graphql:"passAccuracy"`
	PenaltiesSaved     int        `graphql:"penaltiesSaved"`
	PenaltyKickMissed  int        `graphql:"penaltyKickMissed"`
	PenaltySave        int        `graphql:"penaltySave"`
	Player             struct {
		Slug string `graphql:"slug"`
	} `graphql:"player"`
	RedCard        int  `graphql:"redCard"`
	Reviewed       bool `graphql:"reviewed"`
	Saves          int  `graphql:"saves"`
	ShotAccuracy   int  `graphql:"shotAccuracy"`
	ShotEfficiency int  `graphql:"shotEfficiency"`
	SingleGoalGame int  `graphql:"singleGoalGame"`
	Team           struct {
		Team struct {
			Slug string `graphql:"slug"`
		} `graphql:"... on TeamInterface"`
	} `graphql:"team"`
	TotalClearance  int `graphql:"totalClearance"`
	TotalPass       int `graphql:"totalPass"`
	TotalScoringAtt int `graphql:"totalScoringAtt"`
	TotalTackle     int `graphql:"totalTackle"`
	WasFouled       int `graphql:"wasFouled"`
	WonContest      int `graphql:"wonContest"`
	YellowCard      int `graphql:"yellowCard"`
}

type So5Score struct {
	AllAroundStats []StatScore `graphql:"allAroundStats"`
	DecisiveScore  StatScore   `graphql:"decisiveScore"`
	DetailedScore  []StatScore `graphql:"detailedScore"`
	Game           struct {
		Id         graphql.Id `graphql:"id"`
		Date       time.Time  `graphql:"date"`
		So5Fixture struct {
			Slug string `graphql:"slug"`
		} `graphql:"so5Fixture"`
	} `graphql:"game"`
	Id                    graphql.Id  `graphql:"id"`
	NegativeDecisiveStats []StatScore `graphql:"negativeDecisiveStats"`
	Player                struct {
		Slug string `graphql:"slug"`
	} `graphql:"player"`
	PlayerGameStats       PlayerGameStats `graphql:"playerGameStats"`
	Position              string          `graphql:"position"`
	PositionTyped         types.Position  `graphql:"positionTyped"`
	PositiveDecisiveStats []StatScore     `graphql:"positiveDecisiveStats"`
	Score                 decimal.Decimal `graphql:"score"`
	ScoringVersion        int             `graphql:"scoringVersion"`
}
